"""
Network constants
"""

SEED_NODES_IPV4 = [("127.0.0.1", 8888, 4),
                   ("127.0.0.1", 8889, 4),
                   ("fa.decentmesh.net", 8888, 4),
                   ]

SEED_NODES_IPV6 = [("fe.decentmesh.net", 8888, 6)]

BLOCKED_IPV4 = [
    "119.49.152.119",
    "81.7.4.18",
    "185.209.161.202",
    "182.204.179.100",
    "185.192.100.113",
    "103.18.103.20",
    "45.8.127.23",
    "103.169.35.140",
    "45.141.148.3",
    "205.210.31.136",
    "216.239.32.0",
    "173.236.108.54",
    "54.36.148.0",
    "94.202.229.103",
    "159.65.185.136",
    "81.7.4.9",
    "118.194.230.21",
    "111.72.200.202",
    "42.56.238.118",
    "193.169.212.26",
    "115.207.171.225",
    "103.240.252.15",
    "64.68.90.1",  # Googlebot
    "175.155.2.48",
    "81.7.4.4",
    "34.212.0.0",  # Amazon Web Services
    "35.190.247.0",  # Google Cloud Platform
    "159.203.87.186",
    "51.158.21.184",
    "64.68.90.2",  # Googlebot
    "103.18.103.31",
    "103.18.103.58"
]

BLOCKED_IPV6 = [
    "2001:4860:4860::8888",  # Google Public DNS
    "2001:4860:4860::8844",  # Google Public DNS
    "2404:6800:4003:c02::8b",  # Common in Googlebot crawling
    "2607:f8b0:4005:0807:0000:0000:0000:200e",  # Associated with Googlebot activities
    "2001:0db8:85a3:0000:0000:8a2e:0370:7335",  # Malicious IPv6
    "2400:cb00::/32",  # Cloudflare IPv6
    "2001:0db8:85a3:0000:0000:8a2e:0370:7334",  # Malicious IPv6
    "2a00:1450:4001:829::2004"  # Known botnet address
]
